@@ -1,7 +1,8 @@
 from django.conf import settings
-from django.utils.importlib import import_module
-from django.core.exceptions import ImproperlyConfigured
+from django.utils.module_loading import import_string
+
 from templated_email.backends.vanilla_django import TemplateBackend
+from templated_email.utils import InlineImage  # noqa
 
 
 def get_connection(backend=None, template_prefix=None, template_suffix=None,
@@ -13,27 +14,17 @@ def get_connection(backend=None, template_prefix=None, template_suffix=None,
     Both fail_silently and other keyword arguments are used in the
     constructor of the backend.
     """
-    # This method is mostly a copy of the backend loader present in django.core.mail.get_connection
-    klass_path = backend or getattr(settings, 'TEMPLATED_EMAIL_BACKEND', TemplateBackend)
-    if isinstance(klass_path, basestring):
+    # This method is mostly a copy of the backend loader present in
+    # django.core.mail.get_connection
+    klass_path = backend or getattr(settings, 'TEMPLATED_EMAIL_BACKEND',
+                                    TemplateBackend)
+    if isinstance(klass_path, str):
         try:
-            # First check if class name is omited and we have module in settings
-            mod = import_module(klass_path)
-            klass_name = 'TemplateBackend'
-        except ImportError, e:
+            # First check if class name is omitted and we have module in settings
+            klass = import_string(klass_path + '.' + 'TemplateBackend')
+        except ImportError:
             # Fallback to class name
-            try:
-                mod_name, klass_name = klass_path.rsplit('.', 1)
-                mod = import_module(mod_name)
-            except ImportError, e:
-                raise ImproperlyConfigured(
-                    ('Error importing templated email backend module %s: "%s"'
-                     % (mod_name, e)))
-        try:
-            klass = getattr(mod, klass_name)
-        except AttributeError:
-            raise ImproperlyConfigured(('Module "%s" does not define a '
-                                        '"%s" class' % (mod_name, klass_name)))
+            klass = import_string(klass_path)
     else:
         klass = klass_path
 
@@ -44,7 +35,8 @@ def get_connection(backend=None, template_prefix=None, template_suffix=None,
 def get_templated_mail(template_name, context, from_email=None, to=None,
                        cc=None, bcc=None, headers=None,
                        template_prefix=None, template_suffix=None,
-                       template_dir=None, file_extension=None):
+                       template_dir=None, file_extension=None,
+                       create_link=False):
     """Returns a templated EmailMessage instance without a connection using
     the django templating backend."""
     template_prefix = template_prefix or template_dir
@@ -55,13 +47,15 @@ def get_templated_mail(template_name, context, from_email=None, to=None,
                                        from_email=from_email, to=to,
                                        cc=cc, bcc=bcc, headers=headers,
                                        template_prefix=template_prefix,
-                                       template_suffix=template_suffix)
+                                       template_suffix=template_suffix,
+                                       create_link=create_link)
 
 
 def send_templated_mail(template_name, from_email, recipient_list, context,
                         cc=None, bcc=None, fail_silently=False, connection=None,
                         headers=None, template_prefix=None,
-                        template_suffix=None, **kwargs):
+                        template_suffix=None,
+                        create_link=False, **kwargs):
     """Easy wrapper for sending a templated email to a recipient list.
 
     Final behaviour of sending depends on the currently selected engine.
@@ -71,4 +65,4 @@ def send_templated_mail(template_name, from_email, recipient_list, context,
                                               template_suffix=template_suffix)
     return connection.send(template_name, from_email, recipient_list, context,
                            cc=cc, bcc=bcc, fail_silently=fail_silently,
-                           headers=headers, **kwargs)
+                           headers=headers, create_link=create_link, **kwargs)
